@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002  Sam Horrocks
+ * Copyright (C) 2003  Sam Horrocks
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,10 @@
  *
  */
 
+#ifdef PERPERL_BACKEND
+#   define PERL_CORE
+#endif
+
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
